@@ -46,7 +46,8 @@ class Client:
 
     @staticmethod
     def _load_logger(app_name):
-
+        formatter = default_logging_dict['formatters']['default']['format']
+        default_logging_dict['formatters']['default']['format'] = formatter.format(app_name=app_name)
         logging.config.dictConfig(default_logging_dict)
-        return logging.getLogger(app_name)
+        return logging.getLogger('default')
 
